#include <config.h>
#ifdef HAVE_GSTREAMER

#include <gst/gst.h>
#include "mediaplayer.h"

typedef struct _MediaPlayerPrivate {
	GstElement *pipeline, *source, *parser, *decoder, *conv, *scale, *sink;
} MediaPlayerPrivate;




static void
new_pad (GstElement *element,
	 GstPad     *pad,
	 gpointer    data)
{
  /* We can now link this pad with the audio decoder and
   * add both decoder and audio output to the pipeline. */
  MediaPlayerPrivate * private =(MediaPlayerPrivate *) data;
  gst_pad_link (pad, gst_element_get_pad (private->decoder, "sink"));
  gst_bin_add_many (GST_BIN (private->pipeline), private->decoder, private->conv, private->scale, private->sink, NULL);

  /* This function synchronizes a bins state on all of its
   * contained children. */
  gst_bin_sync_children_state (GST_BIN (private->pipeline));
}

gint mediaplayer_init(gint * argc,gchar ** argv[]) {

  guint major, minor, micro;

  gst_init (argc, argv);

  gst_version (&major, &minor, &micro);
  printf ("This program is linked against GStreamer %d.%d.%d\n",
          major, minor, micro);
  return 0;
}



gint mediaplayer_load_sound(const gchar *path,MediaPlayId ** _soundId) {
  MediaPlayerPrivate * soundId=(MediaPlayerPrivate*)malloc(sizeof(MediaPlayerPrivate));
  /* create elements */
  //soundId->pipeline = gst_pipeline_new ("audio-player");
  soundId->pipeline= gst_thread_new ("thread");
  soundId->source = gst_element_factory_make ("filesrc", "file-source");
  soundId->parser = gst_element_factory_make ("oggdemux", "ogg-parser");
  soundId->decoder = gst_element_factory_make ("vorbisdec", "vorbis-decoder");
  soundId->conv = gst_element_factory_make ("audioconvert", "conv");
  soundId->scale = gst_element_factory_make ("audioscale", "scale");
  soundId->sink = gst_element_factory_make ("alsasink", "alsa-output");

  /* set filename property on the file source */
  g_object_set (G_OBJECT (soundId->source), "location", path, NULL);

  /* link together - note that we cannot link the parser and
   * decoder yet, becuse the parser uses dynamic pads. For that,
   * we set a new-pad signal handler. */
  gst_element_link (soundId->source, soundId->parser);
  gst_element_link_many (soundId->decoder, soundId->conv, soundId->scale, soundId->sink, NULL);
  g_signal_connect (soundId->parser, "new-pad", G_CALLBACK (new_pad), soundId);

  /* put all elements in a bin - or at least the ones we will use
   * instantly. */
  gst_bin_add_many (GST_BIN (soundId->pipeline), soundId->source, soundId->parser, NULL);

  /* Now set to playing and iterate. We will set the decoder and
   * audio output to ready so they initialize their memory already.
   * This will decrease the amount of time spent on linking these
   * elements when the Ogg parser emits the new-pad signal. */
  gst_element_set_state (soundId->decoder, GST_STATE_READY);
  gst_element_set_state (soundId->conv, GST_STATE_READY);
  gst_element_set_state (soundId->scale, GST_STATE_READY);
  gst_element_set_state (soundId->sink, GST_STATE_READY);

  *_soundId = (MediaPlayId*) soundId;
  return 0;
}


  

 

gint mediaplayer_unload_sound(MediaPlayId * _soundId) {
  MediaPlayerPrivate * soundId=(MediaPlayerPrivate*)_soundId;
  /* clean up nicely */
  gst_element_set_state (soundId->pipeline, GST_STATE_NULL);
  gst_object_unref (GST_OBJECT (soundId->pipeline));
	
  free(soundId);
  return 0;
}




gint mediaplayer_play_sound(MediaPlayId * _soundId) 
{ 
	MediaPlayerPrivate * soundId=(MediaPlayerPrivate*)_soundId;
	gst_element_set_state (soundId->pipeline, GST_STATE_PLAYING);

	/* and now iterate - the rest will be automatic from here on.
	* When the file is finished, gst_bin_iterate () will return
	* FALSE, thereby terminating this loop. */
	//while (gst_bin_iterate (GST_BIN (pipeline))) ;

	
	return 0;
}

gint mediaplayer_stop_sound(MediaPlayId * _soundId) {
	MediaPlayerPrivate * soundId=(MediaPlayerPrivate*)_soundId;
	gst_element_set_state (soundId->pipeline, GST_STATE_NULL);

	return 0;
}


//not implemented
/*
gint mediaplayer_play_video(const gchar * path)
{
	return 0;
}

*/

#else

gint mediaplayer_init(gint * argc,gchar ** argv[] ) {return 0;}

gint mediaplayer_play_sound(MediaPlayId * soundId) 
{ 	

	return 0;
}

gint mediaplayer_stop_sound(MediaPlayId * soundId) {
	return 0;
}
gint mediaplayer_load_sound(const gchar * path,MediaPlayId ** soundId) {
	return 0;
}
gint mediaplayer_unload_sound(MediaPlayId * soundId) {
	return 0;
}
/*
gint mediaplayer_play_media(const gchar *path) {
	return 0;
}


gint mediaplayer_play_video(const gchar * path)
{
	return 0;
}


gint mediaplayer_play_sound_to_end(const gchar * path)
{
	return 0;
}


gint mediaplayer_play_sound(const gchar *path,gint * soundId) 
{ 
	if(soundId) *soundId = 0;

	return 0;
}

gint mediaplayer_stop_sound(gint soundId) {
	return 0;
}*/

#endif
